@@ -27,6 +27,8 @@ from trytond.tools import safe_eval, datetime_strftime
 from trytond.transaction import Transaction
 from trytond.pyson import Eval, Not, Equal, If, In, Bool, Get, Or, And, \
         PYSONEncoder
+from trytond.pool import Pool
+
 
 
 class DrugDoseUnits(ModelSQL, ModelView):
@@ -261,6 +263,47 @@ class FamilyMember(ModelSQL, ModelView):
 
 FamilyMember()
 
+# Use the template as in Product category.
+
+class MedicamentCategory(ModelSQL, ModelView):    
+    "Medicament Category"
+    _name = "gnuhealth.medicament.category"
+    _description = __doc__
+
+    name = fields.Char('Name', required=True, translate=True)
+    parent = fields.Many2One('gnuhealth.medicament.category','Parent', select=1)
+    childs = fields.One2Many('gnuhealth.medicament.category', 'parent',
+            string='Children')
+
+    def __init__(self):
+        super(MedicamentCategory, self).__init__()
+        self._order.insert(0, ('name', 'ASC'))
+
+        self._constraints += [
+            ('check_recursion', 'recursive_categories'),
+        ]
+        self._error_messages.update({
+            'recursive_categories': 'You can not create recursive categories!',
+        })
+
+    def get_rec_name(self, ids, name):
+        if not ids:
+            return {}
+        res = {}
+        def _name(category):
+            if category.id in res:
+                return res[category.id]
+            elif category.parent:
+                return _name(category.parent) + ' / ' + category.name
+            else:
+                return category.name
+        for category in self.browse(ids):
+            res[category.id] = _name(category)
+        return res
+
+MedicamentCategory()
+
+
 
 class Medicament(ModelSQL, ModelView):
 
@@ -268,10 +311,11 @@ class Medicament(ModelSQL, ModelView):
     _description = __doc__
     _name = "gnuhealth.medicament"
 
-    name = fields.Many2One('product.product', 'Name',
+    name = fields.Many2One('product.product', 'Product',
         domain=[('is_medicament', '=', True)], select="1",
-        help="Commercial Name")
+        help="Product Name", required=True)
     active_component = fields.Char('Active component', help="Active Component")
+    category = fields.Many2One('gnuhealth.medicament.category', 'Category', select= True)
     therapeutic_action = fields.Char('Therapeutic effect',
         help="Therapeutic action")
     composition = fields.Text('Composition', help="Components")
@@ -283,6 +327,46 @@ class Medicament(ModelSQL, ModelView):
         help="The drug represents risk to pregnancy or lactancy")
     pregnancy = fields.Text('Pregnancy and Lactancy',
         help="Warnings for Pregnant Women")
+
+    pregnancy_category = fields.Selection([
+                        ('A', 'A'),
+                        ('B', 'B'),
+                        ('C', 'C'),
+                        ('D', 'D'),
+                        ('X', 'X'),
+                        ('N', 'N'),
+
+                        ], 'Pregnancy Category', select="1",
+                        help='** FDA Pregancy Categories ***\n' \
+                        'CATEGORY A :Adequate and well-controlled human studies have' \
+                        ' failed to demonstrate a risk to the fetus in the' \
+                        ' first trimester of pregnancy (and there is no ' \
+                        'evidence of risk in later trimesters).\n\n' \
+                        'CATEGORY B : Animal reproduction studies have failed to' \
+                        'demonstrate a risk to the fetus and there are no' \
+                        ' adequate and well-controlled studies in pregnant women' \
+                        ' OR Animal studies have shown an adverse effect, but' \
+                        ' adequate and well-controlled studies in pregnant women' \
+                        ' have failed to demonstrate a risk to the fetus in any' \
+                        ' trimester.\n\n'
+                        'CATEGORY C : Animal reproduction studies have shown an adverse' \
+                        ' effect on the fetus and there are no adequate and' \
+                        ' well-controlled studies in humans, but potential benefits' \
+                        ' may warrant use of the drug in pregnant women despite ' \
+                        'potential risks. \n\n' \
+                        ' CATEGORY D : There is positive evidence of human fetal ' \
+                        ' risk based on adverse reaction data from investigational' \
+                        ' or marketing experience or studies in humans, but potential' \
+                        ' benefits may warrant use of the drug in pregnant women despite' \
+                        ' potential risks.\n\n'
+                        'CATEGORY X : Studies in animals or humans have demonstrated' \
+                        ' fetal abnormalities and/or there is positive evidence of human' \
+                        ' fetal risk based on adverse reaction data from investigational' \
+                        ' or marketing experience, and the risks involved in use of the' \
+                        ' drug in pregnant women clearly outweigh potential benefits.\n\n' \
+                        'CATEGORY N : Not yet classified'
+                        )
+    
     presentation = fields.Text('Presentation', help="Packaging")
     adverse_reaction = fields.Text('Adverse Reactions')
     storage = fields.Text('Storage Conditions')
@@ -685,8 +769,8 @@ class PatientData(ModelSQL, ModelView):
             'The Patient already exists !')]
 
     def create(self, values):
-        sequence_obj = self.pool.get('ir.sequence')
-        config_obj = self.pool.get('gnuhealth.sequences')
+        sequence_obj = Pool().get('ir.sequence')
+        config_obj = Pool().get('gnuhealth.sequences')
 
         values = values.copy()
         if not values.get('identification_code'):
@@ -815,8 +899,8 @@ class Appointment (ModelSQL, ModelView):
         self._order.insert(0, ('name', 'DESC'))
 
     def create(self, values):
-        sequence_obj = self.pool.get('ir.sequence')
-        config_obj = self.pool.get('gnuhealth.sequences')
+        sequence_obj = Pool().get('ir.sequence')
+        config_obj = Pool().get('gnuhealth.sequences')
 
         values = values.copy()
         if not values.get('name'):
@@ -1027,13 +1111,13 @@ class PatientPrescriptionOrder(ModelSQL, ModelView):
         return datetime.now()
 
     def default_user_id(self):
-        user_obj = self.pool.get('res.user')
+        user_obj = Pool().get('res.user')
         user = user_obj.browse(Transaction().user)
         return int(user.id)
 
     def create(self, values):
-        sequence_obj = self.pool.get('ir.sequence')
-        config_obj = self.pool.get('gnuhealth.sequences')
+        sequence_obj = Pool().get('ir.sequence')
+        config_obj = Pool().get('gnuhealth.sequences')
 
         values = values.copy()
         if not values.get('prescription_id'):
@@ -1244,12 +1328,30 @@ class PatientEvaluation(ModelSQL, ModelView):
         help='Level of Consciousness - on Glasgow Coma Scale :' \
         '  1=coma - 15=normal',
         on_change_with=['loc_verbal', 'loc_motor', 'loc_eyes'])
-    loc_eyes = fields.Integer('Level of Consciousness - Eyes',
-        help="Eyes Response - Glasgow Coma Scale - 1 to 4")
-    loc_verbal = fields.Integer('Level of Consciousness - Verbal',
-        help="Verbal Response - Glasgow Coma Scale - 1 to 5")
-    loc_motor = fields.Integer('Level of Consciousness - Motor',
-        help="Motor Response - Glasgow Coma Scale - 1 to 6")
+    loc_eyes = fields.Selection([
+       ('1', 'Does not Open Eyes'),
+       ('2', 'Opens eyes in response to painful stimuli'),
+       ('3', 'Opens eyes in response to voice'),
+       ('4', 'Opens eyes spontaneously'),
+        ], 'Glasgow - Eyes', sort=False)
+
+    loc_verbal = fields.Selection([
+       ('1', 'Makes no sounds'),
+       ('2', 'Incomprehensible sounds'),
+       ('3', 'Utters inappropriate words'),
+       ('4', 'Confused, disoriented'),
+       ('5', 'Oriented, converses normally'),
+        ], 'Glasgow - Verbal', sort=False)
+
+    loc_motor = fields.Selection([
+       ('1', 'Makes no movement'),
+       ('2', 'Extension to painful stimuli - decerebrate response -'),
+       ('3', 'Abnormal flexion to painful stimuli (decorticate response)'),
+       ('4', 'Flexion / Withdrawal to painful stimuli'),
+       ('5', 'Localizes painful stimuli'),
+       ('6', 'Obeys commands'),
+        ], 'Glasgow - Motor', sort=False)
+
     tremor = fields.Boolean('Tremor', help='If associated  to a ' \
         'disease, please encode it on the patient disease history')
     violent = fields.Boolean('Violent Behaviour',
@@ -1396,7 +1498,7 @@ class PatientEvaluation(ModelSQL, ModelView):
         loc_motor = vals.get('loc_motor')
         loc_eyes = vals.get('loc_eyes')
         loc_verbal = vals.get('loc_verbal')
-        loc = loc_motor + loc_eyes + loc_verbal
+        loc = int(loc_motor) + int(loc_eyes) + int(loc_verbal)
 
         return loc
 
